@@ -12,7 +12,6 @@ use crate::storage::types::StorageType;
 use crate::storage::Storable;
 use crate::{Direction, ARITY};
 use serde::{Deserialize, Serialize};
-use std::marker::PhantomData;
 use std::{
     convert::TryInto,
     fmt::{self, Debug},
@@ -67,7 +66,7 @@ impl NodeLabel {
     }
 
     /// Returns the prefix of a specified length, and the entire value on an out of range length
-    fn get_prefix(&self, len: u32) -> Self {
+    pub(crate) fn get_prefix(&self, len: u32) -> Self {
         if len >= self.get_len() {
             return *self;
         }
@@ -129,7 +128,7 @@ pub fn hash_label<H: Hasher>(label: NodeLabel) -> H::Digest {
     H::merge_with_int(byte_label_len, label.get_val())
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, Eq, PartialEq)]
 #[serde(bound = "")]
 /// A HistoryNodeState represents the state of a [crate::history_tree_node::HistoryTreeNode] at a given epoch.
 /// As you may see, when looking at [HistoryChildState], the node needs to include
@@ -138,11 +137,11 @@ pub fn hash_label<H: Hasher>(label: NodeLabel) -> H::Digest {
 /// any given epoch, without having to do a traversal of the history tree to find siblings.
 /// The hash value of this node at this state.
 /// To be used in its parent, alongwith the label.
-pub struct HistoryNodeState<H> {
+pub struct HistoryNodeState {
     /// The hash at this node state
     pub value: Vec<u8>,
     /// The states of the children at this time
-    pub child_states: Vec<HistoryChildState<H>>,
+    pub child_states: [Option<HistoryChildState>; ARITY],
     /// A unique key
     pub key: NodeStateKey,
 }
@@ -152,7 +151,30 @@ pub struct HistoryNodeState<H> {
 #[derive(Copy, Clone, Serialize, Deserialize, PartialEq, Eq, Hash, Debug)]
 pub struct NodeStateKey(pub NodeLabel, pub u64);
 
-impl<H: Hasher> Storable for HistoryNodeState<H> {
+impl PartialOrd for NodeStateKey {
+    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+        Some(self.cmp(other))
+    }
+}
+
+impl Ord for NodeStateKey {
+    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
+        //`label_len`, `label_val`, `epoch`
+        let label_cmp = self.0.len.cmp(&other.0.len);
+        if let std::cmp::Ordering::Equal = label_cmp {
+            let value_cmp = self.0.val.cmp(&other.0.val);
+            if let std::cmp::Ordering::Equal = value_cmp {
+                self.1.cmp(&self.1)
+            } else {
+                value_cmp
+            }
+        } else {
+            label_cmp
+        }
+    }
+}
+
+impl Storable for HistoryNodeState {
     type Key = NodeStateKey;
 
     fn data_type() -> StorageType {
@@ -162,28 +184,61 @@ impl<H: Hasher> Storable for HistoryNodeState<H> {
     fn get_id(&self) -> NodeStateKey {
         self.key
     }
+
+    fn get_full_binary_key_id(key: &NodeStateKey) -> Vec<u8> {
+        let mut result = vec![StorageType::HistoryNodeState as u8];
+        let len_bytes = key.0.len.to_be_bytes();
+        for byte in &len_bytes {
+            result.push(*byte);
+        }
+
+        let parts: [[u8; 8]; 2] = [key.0.val.to_be_bytes(), key.1.to_be_bytes()];
+        for iarray in &parts {
+            for byte in iarray {
+                result.push(*byte);
+            }
+        }
+        result
+    }
+
+    fn key_from_full_binary(bin: &[u8]) -> Result<NodeStateKey, String> {
+        if bin.len() < 21 {
+            return Err("Not enough bytes to form a proper key".to_string());
+        }
+
+        let len_bytes: [u8; 4] = bin[1..=4].try_into().expect("Slice with incorrect length");
+        let val_bytes: [u8; 8] = bin[5..=12].try_into().expect("Slice with incorrect length");
+        let epoch_bytes: [u8; 8] = bin[13..=20]
+            .try_into()
+            .expect("Slice with incorrect length");
+        let len = u32::from_be_bytes(len_bytes);
+        let val = u64::from_be_bytes(val_bytes);
+        let epoch = u64::from_be_bytes(epoch_bytes);
+
+        Ok(NodeStateKey(NodeLabel { len, val }, epoch))
+    }
 }
 
-unsafe impl<H: Hasher> Sync for HistoryNodeState<H> {}
+unsafe impl Sync for HistoryNodeState {}
 
-impl<H: Hasher> HistoryNodeState<H> {
+impl HistoryNodeState {
     /// Creates a new [HistoryNodeState]
-    pub fn new(key: NodeStateKey) -> Self {
-        let children = vec![HistoryChildState::<H>::new_dummy(); ARITY];
+    pub fn new<H: Hasher>(key: NodeStateKey) -> Self {
+        const INIT: Option<HistoryChildState> = None;
         HistoryNodeState {
             value: from_digest::<H>(H::hash(&[0u8])).unwrap(),
-            child_states: children,
+            child_states: [INIT; ARITY],
             key,
         }
     }
 
     /// Returns a copy of the child state, in the calling HistoryNodeState in the given direction.
-    pub(crate) fn get_child_state_in_dir(&self, dir: usize) -> HistoryChildState<H> {
+    pub(crate) fn get_child_state_in_dir(&self, dir: usize) -> Option<HistoryChildState> {
         self.child_states[dir].clone()
     }
 }
 
-impl<H: Hasher> Clone for HistoryNodeState<H> {
+impl Clone for HistoryNodeState {
     fn clone(&self) -> Self {
         Self {
             value: self.value.clone(),
@@ -195,109 +250,77 @@ impl<H: Hasher> Clone for HistoryNodeState<H> {
 
 // To use the `{}` marker, the trait `fmt::Display` must be implemented
 // manually for the type.
-impl<H: Hasher> fmt::Display for HistoryNodeState<H> {
+impl fmt::Display for HistoryNodeState {
     // This trait requires `fmt` with this exact signature.
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         writeln!(f, "\tvalue = {:?}", self.value).unwrap();
         for i in 0..ARITY {
-            writeln!(f, "\tchildren {}: {:#}", i, self.child_states[i]).unwrap();
+            writeln!(f, "\tchildren {}: {:?}", i, self.child_states[i]).unwrap();
         }
         write!(f, "")
     }
 }
 
-///  Marks whether a child state is real
-#[derive(Debug, Clone, Copy, PartialEq, Serialize, Deserialize)]
-pub enum DummyChildState {
-    /// If this child is dummy. Usually for children of leaves
-    Dummy,
-    /// If this child is real
-    Real,
-}
-
 /// This struct represents the state of the child of a node at a given epoch
 /// and contains all the information its parent might need about it in an operation.
 /// The dummy_marker represents whether this child was real or a dummy.
 /// In particular, the children of a leaf node are dummies.
-#[derive(Debug, Serialize, Deserialize)]
-pub struct HistoryChildState<H> {
-    ///  Tells you whether this child is a dummy
-    pub dummy_marker: DummyChildState,
+#[derive(Debug, Serialize, Deserialize, Eq)]
+pub struct HistoryChildState {
     /// Says where the child node with this label is located
-    pub location: usize,
+    pub location: u64,
     /// Child node's label
     pub label: NodeLabel,
     /// Child node's hash value
     pub hash_val: Vec<u8>,
     /// Child node's state this epoch being pointed to here
     pub epoch_version: u64,
-    /// Phantom
-    pub _h: PhantomData<H>,
 }
 
 /// parameters are azks_id, node location, epoch, child index
 #[derive(Clone, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub struct ChildStateKey(
     pub(crate) Vec<u8>,
-    pub(crate) usize,
-    pub(crate) usize,
-    pub(crate) usize,
+    pub(crate) u64,
+    pub(crate) u64,
+    pub(crate) u64,
 );
 
-unsafe impl<H: Hasher> Sync for HistoryChildState<H> {}
+unsafe impl Sync for HistoryChildState {}
 
-impl<H: Hasher> HistoryChildState<H> {
+impl HistoryChildState {
     /// Instantiates a new [HistoryChildState] with given label and hash val.
-    pub fn new(loc: usize, label: NodeLabel, hash_val: H::Digest, ep: u64) -> Self {
+    pub fn new<H: Hasher>(loc: u64, label: NodeLabel, hash_val: H::Digest, ep: u64) -> Self {
         HistoryChildState {
-            dummy_marker: DummyChildState::Real,
             location: loc,
             label,
             hash_val: from_digest::<H>(hash_val).unwrap(),
             epoch_version: ep,
-            _h: PhantomData,
-        }
-    }
-
-    /// Creates a dummy [HistoryChildState] to signify a node not having children.
-    /// Used elsewhere to instantiate a leaf node of the
-    /// [crate::history_tree_node::HistoryTreeNode] type.
-    pub fn new_dummy() -> Self {
-        HistoryChildState {
-            dummy_marker: DummyChildState::Dummy,
-            location: 0,
-            label: NodeLabel::new(0, 0),
-            hash_val: from_digest::<H>(H::hash(&[0u8])).unwrap(),
-            epoch_version: 0,
-            _h: PhantomData,
         }
     }
 }
 
-impl<H: Hasher> Clone for HistoryChildState<H> {
+impl Clone for HistoryChildState {
     fn clone(&self) -> Self {
         Self {
-            dummy_marker: self.dummy_marker,
             location: self.location,
             label: self.label,
             hash_val: self.hash_val.clone(),
             epoch_version: self.epoch_version,
-            _h: PhantomData,
         }
     }
 }
 
-impl<H: Hasher> PartialEq for HistoryChildState<H> {
+impl PartialEq for HistoryChildState {
     fn eq(&self, other: &Self) -> bool {
-        self.dummy_marker == other.dummy_marker
-            && self.location == other.location
+        self.location == other.location
             && self.label == other.label
             && self.hash_val == other.hash_val
             && self.epoch_version == other.epoch_version
     }
 }
 
-impl<H: Hasher> fmt::Display for HistoryChildState<H> {
+impl fmt::Display for HistoryChildState {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
             f,
