@@ -31,28 +31,24 @@ type InMemoryDb = storage::memory::AsyncInMemoryDatabase;
 ////////// history_tree_node tests //////
 //  Test set_child_without_hash and get_child_at_existing_epoch
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_set_child_without_hash_at_root() -> Result<(), HistoryTreeNodeError> {
     let ep = 1;
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(ep),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(ep)).await?;
     let child_hist_node_1 =
-        HistoryChildState::new(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
     root.write_to_storage(&db).await?;
-    root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()))
+    root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()))
         .await?;
 
     let set_child = root
-        .get_child_at_existing_epoch(&db, ep, Direction::Some(1))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, ep, Direction::Some(1))
         .await
         .map_err(|_| panic!("Child not set in test_set_child_without_hash_at_root"))
         .unwrap();
     assert!(
-        set_child == child_hist_node_1,
+        set_child == Some(child_hist_node_1),
         "Child in direction is not equal to the set value"
     );
     assert!(
@@ -64,52 +60,48 @@ async fn test_set_child_without_hash_at_root() -> Result<(), HistoryTreeNodeErro
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_set_children_without_hash_at_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
     let ep = 1;
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(ep),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(ep)).await?;
     let child_hist_node_1 =
-        HistoryChildState::new(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
-    let child_hist_node_2: HistoryChildState<Blake3> =
-        HistoryChildState::new(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_2: HistoryChildState =
+        HistoryChildState::new::<Blake3>(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
     root.write_to_storage(&db).await?;
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(0), child_hist_node_2.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(0), child_hist_node_2.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     let set_child_1 = root
-        .get_child_at_existing_epoch(&db, ep, Direction::Some(1))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, ep, Direction::Some(1))
         .await;
     match set_child_1 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_1,
+            child_st == Some(child_hist_node_1),
             "Child in 1 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
     }
 
     let set_child_2 = root
-        .get_child_at_existing_epoch(&db, ep, Direction::Some(0))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, ep, Direction::Some(0))
         .await;
     match set_child_2 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_2,
+            child_st == Some(child_hist_node_2),
             "Child in 0 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
@@ -121,31 +113,27 @@ async fn test_set_children_without_hash_at_root() -> Result<(), HistoryTreeNodeE
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_set_children_without_hash_multiple_at_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
     let mut ep = 1;
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(ep),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(ep)).await?;
     let child_hist_node_1 =
-        HistoryChildState::new(1, NodeLabel::new(11, 2), Blake3::hash(&[0u8]), ep);
-    let child_hist_node_2: HistoryChildState<Blake3> =
-        HistoryChildState::new(2, NodeLabel::new(00, 2), Blake3::hash(&[0u8]), ep);
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(11, 2), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_2: HistoryChildState =
+        HistoryChildState::new::<Blake3>(2, NodeLabel::new(00, 2), Blake3::hash(&[0u8]), ep);
     root.write_to_storage(&db).await?;
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_1))
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_1))
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(0), child_hist_node_2))
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(0), child_hist_node_2))
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
@@ -153,40 +141,40 @@ async fn test_set_children_without_hash_multiple_at_root() -> Result<(), History
 
     ep = 2;
 
-    let child_hist_node_3: HistoryChildState<Blake3> =
-        HistoryChildState::new(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
-    let child_hist_node_4: HistoryChildState<Blake3> =
-        HistoryChildState::new(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_3: HistoryChildState =
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_4: HistoryChildState =
+        HistoryChildState::new::<Blake3>(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
     root.write_to_storage(&db).await?;
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_3.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_3.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(0), child_hist_node_4.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(0), child_hist_node_4.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     let set_child_1 = root
-        .get_child_at_existing_epoch(&db, ep, Direction::Some(1))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, ep, Direction::Some(1))
         .await;
     match set_child_1 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_3,
+            child_st == Some(child_hist_node_3),
             "Child in 1 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
     }
 
     let set_child_2 = root
-        .get_child_at_existing_epoch(&db, ep, Direction::Some(0))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, ep, Direction::Some(0))
         .await;
     match set_child_2 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_4,
+            child_st == Some(child_hist_node_4),
             "Child in 0 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
@@ -198,31 +186,27 @@ async fn test_set_children_without_hash_multiple_at_root() -> Result<(), History
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_get_child_at_existing_epoch_multiple_at_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
     let mut ep = 1;
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(ep),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(ep)).await?;
     let child_hist_node_1 =
-        HistoryChildState::new(1, NodeLabel::new(11, 2), Blake3::hash(&[0u8]), ep);
-    let child_hist_node_2: HistoryChildState<Blake3> =
-        HistoryChildState::new(2, NodeLabel::new(00, 2), Blake3::hash(&[0u8]), ep);
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(11, 2), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_2: HistoryChildState =
+        HistoryChildState::new::<Blake3>(2, NodeLabel::new(00, 2), Blake3::hash(&[0u8]), ep);
     root.write_to_storage(&db).await?;
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_1.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(0), child_hist_node_2.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(0), child_hist_node_2.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
@@ -230,39 +214,39 @@ async fn test_get_child_at_existing_epoch_multiple_at_root() -> Result<(), Histo
 
     ep = 2;
 
-    let child_hist_node_3: HistoryChildState<Blake3> =
-        HistoryChildState::new(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
-    let child_hist_node_4: HistoryChildState<Blake3> =
-        HistoryChildState::new(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_3: HistoryChildState =
+        HistoryChildState::new::<Blake3>(1, NodeLabel::new(1, 1), Blake3::hash(&[0u8]), ep);
+    let child_hist_node_4: HistoryChildState =
+        HistoryChildState::new::<Blake3>(2, NodeLabel::new(0, 1), Blake3::hash(&[0u8]), ep);
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(1), child_hist_node_3.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(1), child_hist_node_3.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     assert!(
-        root.set_child(&db, ep, &(Direction::Some(0), child_hist_node_4.clone()),)
+        root.set_child::<_, Blake3>(&db, ep, &(Direction::Some(0), child_hist_node_4.clone()),)
             .await
             .is_ok(),
         "Setting the child without hash threw an error"
     );
     let set_child_1 = root
-        .get_child_at_existing_epoch(&db, 1, Direction::Some(1))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, 1, Direction::Some(1))
         .await;
     match set_child_1 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_1,
+            child_st == Some(child_hist_node_1),
             "Child in 1 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
     }
 
     let set_child_2 = root
-        .get_child_at_existing_epoch(&db, 1, Direction::Some(0))
+        .get_child_at_existing_epoch::<_, Blake3>(&db, 1, Direction::Some(0))
         .await;
     match set_child_2 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_2,
+            child_st == Some(child_hist_node_2),
             "Child in 0 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
@@ -275,42 +259,38 @@ async fn test_get_child_at_existing_epoch_multiple_at_root() -> Result<(), Histo
 }
 
 //  Test get_child_at_epoch
-#[actix_rt::test]
+#[tokio::test]
 pub async fn test_get_child_at_epoch_at_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
     let init_ep = 0;
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(init_ep),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(init_ep)).await?;
 
     for ep in 0u64..3u64 {
-        let child_hist_node_1 = HistoryChildState::new(
+        let child_hist_node_1 = HistoryChildState::new::<Blake3>(
             ep.try_into().unwrap(),
             NodeLabel::new(0b1u64 << ep.clone(), ep.try_into().unwrap()),
             Blake3::hash(&[0u8]),
             2 * ep,
         );
-        let child_hist_node_2: HistoryChildState<Blake3> = HistoryChildState::new(
+        let child_hist_node_2: HistoryChildState = HistoryChildState::new::<Blake3>(
             ep.try_into().unwrap(),
             NodeLabel::new(0, ep.clone().try_into().unwrap()),
             Blake3::hash(&[0u8]),
             2 * ep,
         );
         root.write_to_storage(&db).await?;
-        root.set_child(&db, 2 * ep, &(Direction::Some(1), child_hist_node_1))
+        root.set_child::<_, Blake3>(&db, 2 * ep, &(Direction::Some(1), child_hist_node_1))
             .await?;
-        root.set_child(&db, 2 * ep, &(Direction::Some(0), child_hist_node_2))
+        root.set_child::<_, Blake3>(&db, 2 * ep, &(Direction::Some(0), child_hist_node_2))
             .await?;
     }
 
     let ep_existing = 0u64;
 
-    let child_hist_node_1 = HistoryChildState::new(
+    let child_hist_node_1 = HistoryChildState::new::<Blake3>(
         0,
         NodeLabel::new(
             0b1u64 << ep_existing.clone(),
@@ -319,27 +299,31 @@ pub async fn test_get_child_at_epoch_at_root() -> Result<(), HistoryTreeNodeErro
         Blake3::hash(&[0u8]),
         2 * ep_existing,
     );
-    let child_hist_node_2: HistoryChildState<Blake3> = HistoryChildState::new(
+    let child_hist_node_2: HistoryChildState = HistoryChildState::new::<Blake3>(
         0,
         NodeLabel::new(0, ep_existing.clone().try_into().unwrap()),
         Blake3::hash(&[0u8]),
         2 * ep_existing,
     );
 
-    let set_child_1 = root.get_child_at_epoch(&db, 1, Direction::Some(1)).await;
+    let set_child_1 = root
+        .get_child_at_epoch::<_, Blake3>(&db, 1, Direction::Some(1))
+        .await;
     match set_child_1 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_1,
+            child_st == Some(child_hist_node_1),
             "Child in 1 is not equal to the set value = {:?}",
             child_st
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
     }
 
-    let set_child_2 = root.get_child_at_epoch(&db, 1, Direction::Some(0)).await;
+    let set_child_2 = root
+        .get_child_at_epoch::<_, Blake3>(&db, 1, Direction::Some(0))
+        .await;
     match set_child_2 {
         Ok(child_st) => assert!(
-            child_st == child_hist_node_2,
+            child_st == Some(child_hist_node_2),
             "Child in 0 is not equal to the set value"
         ),
         Err(_) => panic!("Child not set in test_set_children_without_hash_at_root"),
@@ -353,46 +337,30 @@ pub async fn test_get_child_at_epoch_at_root() -> Result<(), HistoryTreeNodeErro
 
 // insert_single_leaf tests
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_insert_single_leaf_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(0u64),
-    )
-    .await?;
-    let new_leaf = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b0u64, 1u32),
-        1,
-        &[0u8],
-        0,
-        0,
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(0u64)).await?;
+    let new_leaf =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b0u64, 1u32), 1, &[0u8], 0, 0).await?;
 
-    let leaf_1 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b1u64, 1u32),
-        2,
-        &[1u8],
-        0,
-        0,
-    )
-    .await?;
+    let leaf_1 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b1u64, 1u32), 2, &[1u8], 0, 0).await?;
     root.write_to_storage(&db).await?;
 
     let mut num_nodes = 1;
-
-    root.insert_single_leaf(&db, new_leaf.clone(), 0, &mut num_nodes)
-        .await?;
-    root.insert_single_leaf(&db, leaf_1.clone(), 0, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, new_leaf.clone(), 0, &mut num_nodes)
         .await?;
 
-    let root_val = root.get_value(&db).await?;
+    println!("X1.5");
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_1.clone(), 0, &mut num_nodes)
+        .await?;
+    println!("X2");
+
+    let root_val = root.get_value::<_, Blake3>(&db).await?;
 
     let leaf_0_hash = Blake3::merge(&[
         Blake3::merge(&[Blake3::hash(&[]), Blake3::hash(&[0b0u8])]),
@@ -411,51 +379,27 @@ async fn test_insert_single_leaf_root() -> Result<(), HistoryTreeNodeError> {
         ]),
         hash_label::<Blake3>(root.label),
     ]);
-    assert!(root_val == expected, "Root hash not equal to expected");
+    assert_eq!(root_val, expected, "Root hash not equal to expected");
 
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_insert_single_leaf_below_root() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(0u64),
-    )
-    .await?;
-    let new_leaf = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b00u64, 2u32),
-        1,
-        &[0u8],
-        0,
-        1,
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(0u64)).await?;
+    let new_leaf =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b00u64, 2u32), 1, &[0u8], 0, 1).await?;
 
-    let leaf_1 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b11u64, 2u32),
-        2,
-        &[1u8],
-        0,
-        2,
-    )
-    .await?;
+    let leaf_1 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b11u64, 2u32), 2, &[1u8], 0, 2).await?;
 
-    let leaf_2 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b10u64, 2u32),
-        3,
-        &[1u8, 1u8],
-        0,
-        3,
-    )
-    .await?;
+    let leaf_2 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b10u64, 2u32), 3, &[1u8, 1u8], 0, 3)
+            .await?;
 
     let leaf_0_hash = Blake3::merge(&[
         Blake3::merge(&[Blake3::hash(&[]), Blake3::hash(&[0b0u8])]),
@@ -489,16 +433,16 @@ async fn test_insert_single_leaf_below_root() -> Result<(), HistoryTreeNodeError
     root.write_to_storage(&db).await?;
     let mut num_nodes = 1;
 
-    root.insert_single_leaf(&db, new_leaf.clone(), 1, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, new_leaf.clone(), 1, &mut num_nodes)
         .await?;
 
-    root.insert_single_leaf(&db, leaf_1.clone(), 2, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_1.clone(), 2, &mut num_nodes)
         .await?;
 
-    root.insert_single_leaf(&db, leaf_2.clone(), 3, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_2.clone(), 3, &mut num_nodes)
         .await?;
 
-    let root_val = root.get_value(&db).await?;
+    let root_val = root.get_value::<_, Blake3>(&db).await?;
 
     let expected = Blake3::merge(&[
         Blake3::merge(&[
@@ -511,56 +455,26 @@ async fn test_insert_single_leaf_below_root() -> Result<(), HistoryTreeNodeError
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_insert_single_leaf_below_root_both_sides() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(0u64),
-    )
-    .await?;
-    let new_leaf = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b000u64, 3u32),
-        1,
-        &[0u8],
-        0,
-        0,
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(0u64)).await?;
+    let new_leaf =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b000u64, 3u32), 1, &[0u8], 0, 0).await?;
 
-    let leaf_1 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b111u64, 3u32),
-        2,
-        &[1u8],
-        0,
-        0,
-    )
-    .await?;
+    let leaf_1 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b111u64, 3u32), 2, &[1u8], 0, 0).await?;
 
-    let leaf_2 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b100u64, 3u32),
-        3,
-        &[1u8, 1u8],
-        0,
-        0,
-    )
-    .await?;
+    let leaf_2 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b100u64, 3u32), 3, &[1u8, 1u8], 0, 0)
+            .await?;
 
-    let leaf_3 = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        NodeLabel::new(0b010u64, 3u32),
-        4,
-        &[0u8, 1u8],
-        0,
-        0,
-    )
-    .await?;
+    let leaf_3 =
+        get_leaf_node::<Blake3, _>(&db, NodeLabel::new(0b010u64, 3u32), 4, &[0u8, 1u8], 0, 0)
+            .await?;
 
     let leaf_0_hash = Blake3::merge(&[
         Blake3::merge(&[Blake3::hash(&[]), Blake3::hash(&[0b0u8])]),
@@ -597,22 +511,22 @@ async fn test_insert_single_leaf_below_root_both_sides() -> Result<(), HistoryTr
         hash_label::<Blake3>(NodeLabel::new(0b0u64, 1u32)),
     ]);
 
-    let mut leaf_0_as_child = new_leaf.to_node_child_state(&db).await?;
+    let mut leaf_0_as_child = new_leaf.to_node_child_state::<_, Blake3>(&db).await?;
     leaf_0_as_child.hash_val = from_digest::<Blake3>(leaf_0_hash).unwrap();
 
-    let mut leaf_3_as_child = leaf_3.to_node_child_state(&db).await?;
+    let mut leaf_3_as_child = leaf_3.to_node_child_state::<_, Blake3>(&db).await?;
     leaf_3_as_child.hash_val = from_digest::<Blake3>(leaf_3_hash).unwrap();
 
     root.write_to_storage(&db).await?;
     let mut num_nodes = 1;
 
-    root.insert_single_leaf(&db, new_leaf.clone(), 1, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, new_leaf.clone(), 1, &mut num_nodes)
         .await?;
-    root.insert_single_leaf(&db, leaf_1.clone(), 2, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_1.clone(), 2, &mut num_nodes)
         .await?;
-    root.insert_single_leaf(&db, leaf_2.clone(), 3, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_2.clone(), 3, &mut num_nodes)
         .await?;
-    root.insert_single_leaf(&db, leaf_3.clone(), 4, &mut num_nodes)
+    root.insert_single_leaf::<_, Blake3>(&db, leaf_3.clone(), 4, &mut num_nodes)
         .await?;
 
     // let root_val = root.get_value()?;
@@ -628,26 +542,22 @@ async fn test_insert_single_leaf_below_root_both_sides() -> Result<(), HistoryTr
     Ok(())
 }
 
-#[actix_rt::test]
+#[tokio::test]
 async fn test_insert_single_leaf_full_tree() -> Result<(), HistoryTreeNodeError> {
     let mut rng = OsRng;
     let mut azks_id = vec![0u8; 32];
     rng.fill_bytes(&mut azks_id);
-    let db = crate::storage::V2FromV1StorageWrapper::new(InMemoryDb::new());
-    let mut root = get_empty_root::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
-        &db,
-        Option::Some(0u64),
-    )
-    .await?;
+    let db = InMemoryDb::new();
+    let mut root = get_empty_root::<Blake3, _>(&db, Option::Some(0u64)).await?;
     root.write_to_storage(&db).await?;
     let mut num_nodes = 1;
-    let mut leaves = Vec::<HistoryTreeNode<Blake3>>::new();
+    let mut leaves = Vec::<HistoryTreeNode>::new();
     let mut leaf_hashes = Vec::new();
     for i in 0u64..8u64 {
-        let new_leaf = get_leaf_node::<Blake3, crate::storage::V2FromV1StorageWrapper<InMemoryDb>>(
+        let new_leaf = get_leaf_node::<Blake3, _>(
             &db,
             NodeLabel::new(i.clone(), 3u32),
-            leaves.len(),
+            leaves.len() as u64,
             &i.to_ne_bytes(),
             0,
             7 - i,
@@ -700,11 +610,11 @@ async fn test_insert_single_leaf_full_tree() -> Result<(), HistoryTreeNodeError>
 
     for i in 0..8 {
         let ep: u64 = i.try_into().unwrap();
-        root.insert_single_leaf(&db, leaves[7 - i].clone(), ep + 1, &mut num_nodes)
+        root.insert_single_leaf::<_, Blake3>(&db, leaves[7 - i].clone(), ep + 1, &mut num_nodes)
             .await?;
     }
 
-    let root_val = root.get_value(&db).await?;
+    let root_val = root.get_value::<_, Blake3>(&db).await?;
 
     assert!(root_val == expected, "Root hash not equal to expected");
     Ok(())
